package com.fs.his.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.his.domain.FsProjectCate;
import org.apache.ibatis.annotations.Select;

/**
 * 理疗分类Mapper接口
 * 
 * @author fs
 * @date 2026-05-14
 */
public interface FsProjectCateMapper extends BaseMapper<FsProjectCate>{
    /**
     * 查询理疗分类
     * 
     * @param id 理疗分类主键
     * @return 理疗分类
     */
    FsProjectCate selectFsProjectCateById(Long id);

    /**
     * 查询理疗分类列表
     * 
     * @param fsProjectCate 理疗分类
     * @return 理疗分类集合
     */
    List<FsProjectCate> selectFsProjectCateList(FsProjectCate fsProjectCate);

    /**
     * 新增理疗分类
     * 
     * @param fsProjectCate 理疗分类
     * @return 结果
     */
    int insertFsProjectCate(FsProjectCate fsProjectCate);

    /**
     * 修改理疗分类
     * 
     * @param fsProjectCate 理疗分类
     * @return 结果
     */
    int updateFsProjectCate(FsProjectCate fsProjectCate);

    /**
     * 删除理疗分类
     * 
     * @param id 理疗分类主键
     * @return 结果
     */
    int deleteFsProjectCateById(Long id);

    /**
     * 批量删除理疗分类
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteFsProjectCateByIds(Long[] ids);

    @Select("SELECT id,cate_name FROM fs_project_cate where status = 1")
    List<FsProjectCate> selectFsProjectCateListOptions();
}
